/**
 * A Mega164P LCD Test
 *
 * Ruibing Wang (rw98@cornell.edu)
 */

 /**
 * Mega164P DIP Pinout
 * 							___________
 * PB0 (PCINT8/XCK0/T0)		|1		40| PA0 (ADC0/PCINT0)
 * PB1 (PCINT9/CLK0/T1)		|2		39| PA1 (ADC1/PCINT1)
 * PB2 (PCINT10/INT2/AIN0)	|3		38| PA2 (ADC2/PCINT2)
 * PB3 (PCINT11/OC0A/AIN1)	|4		37| PA3 (ADC3/PCINT3)
 * PB4 (PCINT12/OCOB/SS)	|5		36| PA4 (ADC4/PCINT4)
 * PB5 (PCINT13/MOSI)		|6		35| PA5 (ADC5/PCINT5)
 * PB6 (PCINT14/MISO)		|7		34| PA6 (ADC6/PCINT6)
 * PB7 (PCINT15/SCK)		|8		33| PA7 (ADC7/PCINT7)
 * RESET					|9		32| AREF
 * VCC						|10		31| GND
 * GND						|11		30| AVCC
 * XTAL2					|12		29| PC7 (TOSC2/PCINT23)
 * XTAL1					|13		28| PC6 (TOSC1/PCINT22)
 * PD0 (PCINT24/RXD0)		|14		27| PC5 (TDI/PCINT21)
 * PD1 (PCINT25/TXD0)		|15		26| PC4 (TDO/PCINT20)
 * PD2 (PCINT26/RXD1/INT0)	|16		25| PC3 (TMS/PCINT19)
 * PD3 (PCINT27/TXD1/INT1)	|17		24| PC2 (TCK/PCINT18)
 * PD4 (PCINT28/XCK1/OC1B)	|18		23| PC1 (SDA/PCINT17)
 * PD5 (PCINT29/OC1A)		|19		22| PC0 (SCL/PCINT16)
 * PD6 (PCINT30/OC2B/ICP)	|20		21| PD7 (OC2/PCINT31)
 *							-----------
 */

/** 
 * Use an 2x16 alphanumeric LCD connected to PORTC as follows:
 *  
 *	[LCD] -	[Mega324P Pin]
 *	1 GND -	GND
 *	2 +5V -	VCC
 *	3 VLC 10k trimpot wiper (trimpot ends go to +5 and gnd) 
 *	4 RS -	PC0
 *	5 RD -	PC1
 *	6 EN -	PC2
 *	11 D4 -	PC4
 *	12 D5 -	PC5
 *	13 D6 -	PC6
 *	14 D7 -	PC7 
 */
#include <avr/io.h>
#include <util/delay.h>
#include <avr/pgmspace.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "lcd_lib.h"

const int8_t LCD_initialize[] PROGMEM = "LCD Initialized\0";
const int8_t LCD_line[] PROGMEM = "line 2\0";
const int8_t LCD_number[] PROGMEM = "Number=\0";

int8_t lcd_buffer[17];	// LCD display buffer
uint16_t count;								//a number to display on the LCD  
uint8_t anipos, dir;						//move a character around  

void init_lcd(void);

int main(void) {
	init_lcd();
	
	_delay_ms(500);
	LCDclr();
	
	CopyStringtoLCD(LCD_line, 8, 1);	
	
	CopyStringtoLCD(LCD_number, 0, 0);	
	
	count=0;
	anipos = 0;
	LCDGotoXY(anipos,1);		//second line
	LCDsendChar('o');

	while (1) {
		sprintf(lcd_buffer,"%-i",count++);	//increment and format string                  
		LCDGotoXY(7, 0);
		LCDstring(lcd_buffer, strlen(lcd_buffer));		// display the count 
      	
		LCDGotoXY(anipos,1);	   //second line
      	LCDsendChar(' '); 
      	
		if (anipos>=7) 
      		dir=-1;
		if (anipos<=0 ) dir=1;
			anipos=anipos+dir;
		LCDGotoXY(anipos,1);	   //second line
		LCDsendChar('o');
      	
		_delay_ms(200);    //never do this in a realtime program
   }
}

void init_lcd(void) {
	LCDinit();	//initialize the display
	LCDcursorOFF();
	LCDclr();				//clear the display

	LCDGotoXY(0,0);
	CopyStringtoLCD(LCD_initialize, 0, 0);
}	
